<?php

namespace XenGenTr\ResimliOneCikanKonular\XF\Pub\Controller;

use XF\Mvc\ParameterBag;

class Thread extends XFCP_Thread
{
	public function actionIndex(ParameterBag $params)
	{
		$reply = parent::actionIndex($params);
		
		if (!$reply instanceof \XF\Mvc\Reply\View)
		{
			return $reply;
		}
		
		$thread = $reply->getParam('thread');
		
		if ($thread)
		{
			$reply->setParam('onecikan', $this->repository('XenGenTr\ResimliOneCikanKonular:OneCikan')->fetchOneCikanByThread($thread));
		}
		
		return $reply;
	}
	
	public function actionOneCikanEdit(ParameterBag $params)
	{
		$visitor = \XF::visitor();

        if (!$visitor->canOnecikarabilir())
		{
			return $this->noPermission();
		}
		
		$thread = $this->assertViewableThread($params->thread_id);
		$onecikan = $thread->Onecikan;
		
		if ($onecikan && !$onecikan->canEdit())
		{
			return $this->noPermission();
		}
		
		if ($this->isPost())
		{
			if (!$onecikan)
			{
				$onecikan = $this->em()->create('XenGenTr\ResimliOneCikanKonular:OneCikan');
			}
			
			if ($upload = $this->request->getFile('upload', false, false))
			{
				$this->repository('XenGenTr\ResimliOneCikanKonular:OneCikan')->setOneCikanFromUpload($thread, $upload);
			}
			
			$input = $this->filter('onecikan', 'array');
			$input['thread_id'] = $thread->thread_id;
			$input['onecikan_baslik'] = !empty($input['onecikan_baslik']) ? $input['onecikan_baslik'] : '';
			$input['onecikan_aciklama'] = !empty($input['onecikan_aciklama']) ? $input['onecikan_aciklama'] : '';
			
			$date = $this->filter('date', 'datetime');
			$time = $this->filter('time', 'str');
			list ($hour, $min) = explode(':', $time);
			
			$dateTime = new \DateTime('@'.$date);
			$dateTime->setTimeZone(\XF::language()->getTimeZone());
			$dateTime->setTime($hour, $min);
			$input['onecikan_tarih'] = $dateTime->getTimestamp();
			
			$form = $this->formAction();
			$form->basicEntitySave($onecikan, $input);
			$form->run();
			
			return $this->redirect($this->buildLink('threads', $thread));
		}
		
		$viewParams = [
			'thread' => $thread,
			'onecikan' => $onecikan,
		];
		
		return $this->view('XenGenTr\ResimliOneCikanKonular:Thread\OneCikanEdit', 'xgt_OneCikan_Konular_Duzenle', $viewParams);
	}
	
	public function actionOneCikanDelete(ParameterBag $params)
	{
		$onecikan = $this->assertOneCikanExists($params->thread_id, 'Thread');
		
		if (!$onecikan->canEdit())
		{
			return $this->noPermission();
		}
		
		if (!$onecikan->preDelete())
		{
			return $this->error($onecikan->getErrors());
		}

		if ($this->isPost())
		{
			$onecikan->delete();
			return $this->redirect($this->buildLink('threads', $onecikan));
		}
		else
		{
			$viewParams = [
				'onecikan' => $onecikan
			];
			return $this->view('XenGenTr\ResimliOneCikanKonular:OneCikan\Delete', 'xgt_OneCikan_Konular_Sil', $viewParams);
		}
	}
	
	protected function assertOneCikanExists($id, $with = null, $phraseKey = null)
	{
		return $this->assertRecordExists('XenGenTr\ResimliOneCikanKonular:OneCikan', $id, $with, $phraseKey);
	}
}